//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yaku](index.md)/[furoLoss](furo-loss.md)

# furoLoss

[common]\
val [furoLoss](furo-loss.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) = 0

副露降低多少番数
